@@ -12,6 +12,7 @@ import (
 func (root *Root) draw() {
 	m := root.Doc
 
+	root.Screen.Clear()
 	if m.BufEndNum() == 0 || root.vHight == 0 {
 		m.topLN = 0
 		root.statusDraw()
@@ -51,7 +52,7 @@ func (root *Root) drawHeader() int {
 	lY := m.SkipLines
 	lX := 0
 	wrap := 0
-	for hy := 0; lY < m.Header+m.SkipLines; hy++ {
+	for hy := 0; lY < m.firstLine(); hy++ {
 		if hy > root.vHight {
 			break
 		}
@@ -100,7 +101,7 @@ func (root *Root) drawHeader() int {
 func (root *Root) drawBody(lX int, lY int) (int, int) {
 	m := root.Doc
 
-	listX, err := root.leftMostX(m.topLN + lY)
+	listX, err := root.leftMostX(m.topLN + root.Doc.firstLine() + lY)
 	if err != nil {
 		log.Println(err, "drawBody", m.topLN+lY)
 	}
@@ -111,6 +112,8 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 	var lineStr string
 	var byteMap map[int]int
 
+	markStyleWidth := min(root.vWidth, root.Doc.general.MarkStyleWidth)
+
 	for y := root.headerLen(); y < root.vHight-1; y++ {
 		if lastLY != lY {
 			lc = root.getLineContents(m.topLN+lY, m.TabWidth)
@@ -130,8 +133,13 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 		}
 
 		// search highlight
-		if root.input.reg != nil {
-			poss := searchPosition(lineStr, root.input.reg)
+		if root.searchWord != "" {
+			var poss [][]int
+			if root.Config.RegexpSearch {
+				poss = searchPositionReg(lineStr, root.searchReg)
+			} else {
+				poss = searchPosition(root.Config.CaseSensitive, lineStr, root.searchWord)
+			}
 			for _, r := range poss {
 				root.searchHighlight(lc, byteMap[r[0]], byteMap[r[1]])
 			}
@@ -139,7 +147,7 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 
 		// line number mode
 		if m.LineNumMode {
-			lc := strToContents(fmt.Sprintf("%*d", root.startX-1, m.topLN+lY-m.Header+1), m.TabWidth)
+			lc := strToContents(fmt.Sprintf("%*d", root.startX-1, m.topLN+lY-m.firstLine()+1), m.TabWidth)
 			for i := 0; i < len(lc); i++ {
 				lc[i].style = applyStyle(tcell.StyleDefault, root.StyleLineNumber)
 			}
@@ -172,6 +180,15 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 				}
 			}
 		}
+
+		// mark style.
+		if intContains(m.marked, m.topLN+lY) {
+			for x := 0; x < markStyleWidth; x++ {
+				r, c, style, _ := root.GetContent(x, y)
+				root.SetContent(x, y, r, c, applyStyle(style, root.StyleMarkLine))
+			}
+		}
+
 		lY = nextY
 	}
 
@@ -211,13 +228,6 @@ func (root *Root) getLineContents(lN int, tabWidth int) lineContents {
 	return lc
 }
 
-// drawEOL fills with blanks from the end of the line to the screen width.
-func (root *Root) drawEOL(eol int, y int) {
-	for x := eol; x < root.vWidth; x++ {
-		root.Screen.SetContent(x, y, DefaultContent.mainc, DefaultContent.combc, DefaultContent.style)
-	}
-}
-
 // wrapContents wraps and draws the contents and returns the next drawing position.
 func (root *Root) wrapContents(y int, lX int, lY int, lc lineContents) (int, int) {
 	if lX < 0 {
@@ -228,7 +238,6 @@ func (root *Root) wrapContents(y int, lX int, lY int, lc lineContents) (int, int
 	for x := 0; ; x++ {
 		if lX+x >= len(lc) {
 			// EOL
-			root.drawEOL(root.startX+x, y)
 			lX = 0
 			lY++
 			break
@@ -236,7 +245,6 @@ func (root *Root) wrapContents(y int, lX int, lY int, lc lineContents) (int, int
 		content := lc[lX+x]
 		if x+content.width+root.startX > root.vWidth {
 			// EOL
-			root.drawEOL(root.startX+x, y)
 			lX += x
 			break
 		}
@@ -255,7 +263,6 @@ func (root *Root) noWrapContents(y int, lX int, lY int, lc lineContents) (int, i
 	for x := 0; root.startX+x < root.vWidth; x++ {
 		if lX+x >= len(lc) {
 			// EOL
-			root.drawEOL(root.startX+x, y)
 			break
 		}
 		content := DefaultContent
@@ -314,11 +321,18 @@ func (root *Root) statusDraw() {
 	leftStatus := fmt.Sprintf("%s%s%s:%s", number, follow, root.Doc.FileName, root.message)
 	leftContents := strToContents(leftStatus, -1)
 	input := root.input
-	caseSensitive := ""
-	if root.CaseSensitive && (input.mode == Search || input.mode == Backsearch) {
-		caseSensitive = "(Aa)"
+	searchMode := ""
+	if input.mode == Search || input.mode == Backsearch {
+		if root.Config.RegexpSearch {
+			searchMode += "(R)"
+		}
+		if root.Config.Incsearch {
+			searchMode += "(I)"
+		}
+		if root.CaseSensitive {
+			searchMode += "(Aa)"
+		}
 	}
-
 	switch input.mode {
 	case Normal:
 		color := tcell.ColorWhite
@@ -331,7 +345,7 @@ func (root *Root) statusDraw() {
 		}
 		root.Screen.ShowCursor(len(leftContents), root.statusPos)
 	default:
-		p := caseSensitive + input.EventInput.Prompt()
+		p := searchMode + input.EventInput.Prompt()
 		leftStatus = p + input.value
 		root.Screen.ShowCursor(len(p)+input.cursorX, root.statusPos)
 		leftContents = strToContents(leftStatus, -1)
@@ -355,3 +369,12 @@ func (root *Root) setContentString(vx int, vy int, lc lineContents) {
 	}
 	screen.SetContent(vx+len(lc), vy, 0, nil, tcell.StyleDefault.Normal())
 }
+
+func intContains(list []int, e int) bool {
+	for _, n := range list {
+		if e == n {
+			return true
+		}
+	}
+	return false
+}
