@@ -48,15 +48,15 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 		case *eventPaste:
 			root.getClipboard(ctx)
 		case *eventSearch:
-			root.search(ctx, root.Doc.topLN+root.Doc.Header+1, root.searchLine)
+			root.forwardSearch(ctx, root.Doc.topLN+root.Doc.firstLine()+1, root.input.value)
 		case *eventBackSearch:
-			root.search(ctx, root.Doc.topLN+root.Doc.Header-1, root.backSearchLine)
+			root.backSearch(ctx, root.Doc.topLN+root.Doc.firstLine()-1, root.input.value)
 		case *viewModeInput:
 			root.setViewMode(ev.value)
 		case *searchInput:
-			root.forwardSearch(ctx, ev.value)
+			root.forwardSearch(ctx, root.Doc.topLN+root.Doc.firstLine(), ev.value)
 		case *backSearchInput:
-			root.backSearch(ctx, ev.value)
+			root.backSearch(ctx, root.Doc.topLN+root.Doc.firstLine(), ev.value)
 		case *gotoInput:
 			root.goLine(ev.value)
 		case *headerInput:
@@ -77,7 +77,7 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			case Normal:
 				root.keyCapture(ev)
 			default:
-				root.inputEvent(ev)
+				root.inputEvent(ctx, ev)
 			}
 		case nil:
 			close(quitChan)
@@ -282,11 +282,12 @@ func (root *Root) Search(str string) {
 		return
 	}
 	if str == "" {
-		root.input.reg = nil
+		root.searchWord = ""
+		root.searchReg = nil
 		return
 	}
-	root.input.value = str
-	root.input.reg = regexpComple(str, root.CaseSensitive)
+	root.searchWord = str
+	root.searchReg = regexpCompile(str, root.CaseSensitive)
 	ev := &eventSearch{}
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
@@ -303,11 +304,12 @@ func (root *Root) BackSearch(str string) {
 		return
 	}
 	if str == "" {
-		root.input.reg = nil
+		root.searchWord = ""
+		root.searchReg = nil
 		return
 	}
-	root.input.value = str
-	root.input.reg = regexpComple(str, root.CaseSensitive)
+	root.searchWord = str
+	root.searchReg = regexpCompile(str, root.CaseSensitive)
 	ev := &eventBackSearch{}
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
@@ -394,9 +396,13 @@ func (root *Root) searchQuit() {
 	}
 }
 
-func (root *Root) cancelWait(cancel context.CancelFunc) error {
+func (root *Root) cancelWait() error {
 	cancelApp := func(ev *tcell.EventKey) *tcell.EventKey {
-		cancel()
+		if root.cancelFunc != nil {
+			root.cancelFunc()
+			root.setMessage("cancel")
+			root.cancelFunc = nil
+		}
 		return nil
 	}
 
