@@ -1,7 +1,6 @@
 package oviewer
 
 import (
-	"bytes"
 	"fmt"
 	"io"
 	"strings"
@@ -32,6 +31,8 @@ const (
 	actionMoveHfUp       = "page_half_up"
 	actionMoveHfDn       = "page_half_down"
 	actionMark           = "mark"
+	actionRemoveMark     = "remove_mark"
+	actionRemoveAllMark  = "remove_all_mark"
 	actionMoveMark       = "next_mark"
 	actionMovePrevMark   = "previous_mark"
 	actionViewMode       = "set_view_mode"
@@ -52,6 +53,10 @@ const (
 	actionPreviousDoc    = "previous_doc"
 	actionCloseDoc       = "close_doc"
 	actionToggleMouse    = "toggle_mouse"
+
+	inputCaseSensitive = "input_casesensitive"
+	inputIncSearch     = "input_incsearch"
+	inputRegexpSearch  = "input_regexp_search"
 )
 
 func (root *Root) setHandler() map[string]func() {
@@ -83,7 +88,9 @@ func (root *Root) setHandler() map[string]func() {
 		actionColumnMode:     root.toggleColumnMode,
 		actionAlternate:      root.toggleAlternateRows,
 		actionLineNumMode:    root.toggleLineNumMode,
-		actionMark:           root.markLineNum,
+		actionMark:           root.addMark,
+		actionRemoveMark:     root.removeMark,
+		actionRemoveAllMark:  root.removeAllMark,
 		actionSearch:         root.setSearchMode,
 		actionBackSearch:     root.setBackSearchMode,
 		actionDelimiter:      root.setDelimiterMode,
@@ -97,6 +104,9 @@ func (root *Root) setHandler() map[string]func() {
 		actionPreviousDoc:    root.previousDoc,
 		actionCloseDoc:       root.closeDocument,
 		actionToggleMouse:    root.toggleMouse,
+		inputCaseSensitive:   root.inputCaseSensitive,
+		inputIncSearch:       root.inputIncSearch,
+		inputRegexpSearch:    root.inputRegexpSearch,
 	}
 }
 
@@ -134,6 +144,8 @@ func GetKeyBinds(bind map[string][]string) map[string][]string {
 		actionAlternate:      {"C"},
 		actionLineNumMode:    {"G"},
 		actionMark:           {"m"},
+		actionRemoveAllMark:  {"ctrl+delete"},
+		actionRemoveMark:     {"M"},
 		actionSearch:         {"/"},
 		actionBackSearch:     {"?"},
 		actionDelimiter:      {"d"},
@@ -147,6 +159,10 @@ func GetKeyBinds(bind map[string][]string) map[string][]string {
 		actionPreviousDoc:    {"["},
 		actionCloseDoc:       {"ctrl+k"},
 		actionToggleMouse:    {"ctrl+alt+r"},
+
+		inputCaseSensitive: {"alt+c"},
+		inputIncSearch:     {"alt+i"},
+		inputRegexpSearch:  {"alt+r"},
 	}
 
 	for k, v := range bind {
@@ -158,6 +174,7 @@ func GetKeyBinds(bind map[string][]string) map[string][]string {
 
 func (root *Root) setKeyBind(keyBind map[string][]string) error {
 	c := root.keyConfig
+	in := root.inputKeyConfig
 
 	actionHandlers := root.setHandler()
 
@@ -166,20 +183,30 @@ func (root *Root) setKeyBind(keyBind map[string][]string) error {
 		if handler == nil {
 			return fmt.Errorf("%w for [%s] unknown action", ErrFailedKeyBind, a)
 		}
-		for _, k := range keys {
-			mod, key, ch, err := cbind.Decode(k)
-			if err != nil {
-				return fmt.Errorf("%w [%s] for %s: %s", ErrFailedKeyBind, k, a, err)
-			}
-			if key == tcell.KeyRune {
-				c.SetRune(mod, ch, wrapEventHandler(handler))
-				// Added "shift+N" instead of 'N' to get it on windows.
-				if 'A' <= ch && ch <= 'Z' {
-					c.SetRune(mod|tcell.ModShift, ch, wrapEventHandler(handler))
-				}
-			} else {
-				c.SetKey(mod, key, wrapEventHandler(handler))
+
+		if strings.HasPrefix(a, "input_") {
+			setHandler(in, handler, a, keys)
+			continue
+		}
+		setHandler(c, handler, a, keys)
+	}
+	return nil
+}
+
+func setHandler(c *cbind.Configuration, handler func(), name string, keys []string) error {
+	for _, k := range keys {
+		mod, key, ch, err := cbind.Decode(k)
+		if err != nil {
+			return fmt.Errorf("%w [%s] for %s: %s", ErrFailedKeyBind, k, name, err)
+		}
+		if key == tcell.KeyRune {
+			c.SetRune(mod, ch, wrapEventHandler(handler))
+			// Added "shift+N" instead of 'N' to get it on windows.
+			if 'A' <= ch && ch <= 'Z' {
+				c.SetRune(mod|tcell.ModShift, ch, wrapEventHandler(handler))
 			}
+		} else {
+			c.SetKey(mod, key, wrapEventHandler(handler))
 		}
 	}
 	return nil
@@ -199,7 +226,7 @@ func (root *Root) keyCapture(ev *tcell.EventKey) bool {
 
 // KeyBindString returns keybind as a string for help.
 func KeyBindString(k KeyBind) string {
-	var b bytes.Buffer
+	var b strings.Builder
 	fmt.Fprintf(&b, "\n\tKey binding\n\n")
 	k.writeKeyBind(&b, actionExit, "quit")
 	k.writeKeyBind(&b, actionCancel, "cancel")
@@ -231,6 +258,8 @@ func KeyBindString(k KeyBind) string {
 
 	fmt.Fprintf(&b, "\n\tMark position\n\n")
 	k.writeKeyBind(&b, actionMark, "mark current position")
+	k.writeKeyBind(&b, actionRemoveMark, "remove mark current position")
+	k.writeKeyBind(&b, actionRemoveAllMark, "remove all mark")
 	k.writeKeyBind(&b, actionMoveMark, "move to next marked position")
 	k.writeKeyBind(&b, actionMovePrevMark, "move to previous marked position")
 
@@ -250,8 +279,13 @@ func KeyBindString(k KeyBind) string {
 	k.writeKeyBind(&b, actionViewMode, "view mode selection")
 	k.writeKeyBind(&b, actionDelimiter, "delimiter string")
 	k.writeKeyBind(&b, actionHeader, "number of header lines")
+	k.writeKeyBind(&b, actionSkipLines, "number of skip lines")
 	k.writeKeyBind(&b, actionTabWidth, "TAB width")
 
+	fmt.Fprintf(&b, "\n\tKey binding when typing\n\n")
+	k.writeKeyBind(&b, inputCaseSensitive, "case-sensitive toggle")
+	k.writeKeyBind(&b, inputRegexpSearch, "regular expression search toggle")
+	k.writeKeyBind(&b, inputIncSearch, "incremental search toggle")
 	return b.String()
 }
 
