@@ -8,6 +8,7 @@ import (
 	"log"
 	"os"
 	"os/signal"
+	"regexp"
 	"strings"
 	"sync"
 	"syscall"
@@ -41,8 +42,20 @@ type Root struct {
 	screenMode ScreenMode
 	// input contains the input mode.
 	input *Input
+	// Original position at the start of search.
+	OriginPos int
+	// Original string.
+	OriginStr string
+	//
+	cancelFunc context.CancelFunc
+
+	searchWord string
+	searchReg  *regexp.Regexp
+
 	// keyConfig contains the binding settings for the key.
 	keyConfig *cbind.Configuration
+	// inputKeyConfig contains the binding settings for the key.
+	inputKeyConfig *cbind.Configuration
 
 	// message is the message to display.
 	message string
@@ -121,6 +134,8 @@ type general struct {
 	FollowMode bool
 	// Follow all.
 	FollowAll bool
+	// MarkStyleWidth is width to apply the style of the marked line.
+	MarkStyleWidth int
 }
 
 // Config represents the settings of ov.
@@ -141,6 +156,8 @@ type Config struct {
 	StyleSearchHighlight ovStyle
 	// StyleColumnHighlight is the style that applies to the column highlight.
 	StyleColumnHighlight ovStyle
+	// StyleMarkLine is a style that marked line.
+	StyleMarkLine ovStyle
 
 	// Old setting method.
 	// Alternating background color.
@@ -163,8 +180,12 @@ type Config struct {
 	AfterWrite bool
 	// QuiteSmall Quit if the output fits on one screen.
 	QuitSmall bool
-	// CaseSensitive is case-sensitive if true
+	// CaseSensitive is case-sensitive if true.
 	CaseSensitive bool
+	// RegexpSearch is Regular expression search if true.
+	RegexpSearch bool
+	// Incsearch is incremental server if true.
+	Incsearch bool
 	// Debug represents whether to enable the debug output.
 	Debug bool
 
@@ -220,6 +241,8 @@ var (
 	ErrFatalCache = errors.New("fatal error in cache value")
 	// ErrMissingFile indicates that the file does not exist.
 	ErrMissingFile = errors.New("missing filename")
+	// ErrIsDirectory indicates that specify a directory instead of a file.
+	ErrIsDirectory = errors.New("is a directory")
 	// ErrNotFound indicates not found.
 	ErrNotFound = errors.New("not found")
 	// ErrCancel indicates cancel.
@@ -245,6 +268,7 @@ func NewOviewer(docs ...*Document) (*Root, error) {
 	}
 	root.Config = NewConfig()
 	root.keyConfig = cbind.NewConfiguration()
+	root.inputKeyConfig = cbind.NewConfiguration()
 	root.DocList = append(root.DocList, docs...)
 	root.Doc = root.DocList[0]
 	root.input = NewInput()
@@ -286,27 +310,41 @@ func NewConfig() Config {
 		StyleColumnHighlight: ovStyle{
 			Reverse: true,
 		},
+		StyleMarkLine: ovStyle{
+			Background: "darkgoldenrod",
+		},
 		General: general{
-			TabWidth: 8,
+			TabWidth:       8,
+			MarkStyleWidth: 1,
 		},
 	}
 }
 
 // Open reads the file named of the argument and return the structure of oviewer.
 func Open(fileNames ...string) (*Root, error) {
-	if len(fileNames) == 0 {
+	switch len(fileNames) {
+	case 0:
 		return openSTDIN()
+	case 1:
+		m, err := openFile(fileNames[0])
+		if err != nil {
+			return nil, err
+		}
+		return NewOviewer(m)
+	default:
+		return openFiles(fileNames)
 	}
-	return openFiles(fileNames)
+
 }
 
+// NewRoot returns the structure of the oviewer.
 func NewRoot(read io.Reader) (*Root, error) {
 	m, err := NewDocument()
 	if err != nil {
 		return nil, err
 	}
 
-	if err = m.ReadAll(read); err != nil {
+	if err := m.ReadAll(read); err != nil {
 		return nil, err
 	}
 	return NewOviewer(m)
@@ -319,35 +357,39 @@ func openSTDIN() (*Root, error) {
 		return nil, err
 	}
 
-	if err = m.ReadFile(""); err != nil {
+	if err := m.ReadFile(""); err != nil {
 		return nil, err
 	}
 	docList = append(docList, m)
 	return NewOviewer(docList...)
 }
 
+func openFile(fileName string) (*Document, error) {
+	fi, err := os.Stat(fileName)
+	if err != nil {
+		return nil, err
+	}
+	if fi.IsDir() {
+		return nil, fmt.Errorf("%s %w", fileName, ErrIsDirectory)
+	}
+	m, err := NewDocument()
+	if err != nil {
+		return nil, err
+	}
+	if err := m.ReadFile(fileName); err != nil {
+		return nil, err
+	}
+	return m, nil
+}
+
 func openFiles(fileNames []string) (*Root, error) {
 	docList := make([]*Document, 0)
 	for _, fileName := range fileNames {
-		fi, err := os.Stat(fileName)
+		m, err := openFile(fileName)
 		if err != nil {
-			log.Println(err, fileName)
+			log.Println(err)
 			continue
 		}
-		if fi.IsDir() {
-			continue
-		}
-
-		m, err := NewDocument()
-		if err != nil {
-			return nil, err
-		}
-
-		if err := m.ReadFile(fileName); err != nil {
-			log.Println(err, fileName)
-			continue
-		}
-
 		docList = append(docList, m)
 	}
 
@@ -729,3 +771,25 @@ func min(a, b int) int {
 	}
 	return b
 }
+
+func removeStr(list []string, s string) []string {
+	if len(s) == 0 {
+		return list
+	}
+
+	for n, l := range list {
+		if l == s {
+			list = append(list[:n], list[n+1:]...)
+		}
+	}
+	return list
+}
+
+func removeInt(list []int, c int) []int {
+	for n, l := range list {
+		if l == c {
+			list = append(list[:n], list[n+1:]...)
+		}
+	}
+	return list
+}
