@@ -38,7 +38,6 @@ func TestRoot_contains(t *testing.T) {
 			fields: fields{
 				input: &Input{
 					value: "test",
-					reg:   regexp.MustCompile(`test`),
 				},
 			},
 			args: args{
@@ -51,8 +50,7 @@ func TestRoot_contains(t *testing.T) {
 			name: "testEscapeSequences2",
 			fields: fields{
 				input: &Input{
-					value: "test",
-					reg:   regexp.MustCompile(`m`),
+					value: "m",
 				},
 			},
 			args: args{
@@ -66,7 +64,6 @@ func TestRoot_contains(t *testing.T) {
 			fields: fields{
 				input: &Input{
 					value: "test",
-					reg:   regexp.MustCompile(`test`),
 				},
 			},
 			args: args{
@@ -81,7 +78,9 @@ func TestRoot_contains(t *testing.T) {
 			root := &Root{
 				input: tt.fields.input,
 			}
-			if got := root.contains(tt.args.s, tt.args.searchType); got != tt.want {
+			root.searchWord = root.input.value
+			root.searchReg = regexp.MustCompile(root.input.value)
+			if got := root.contains(tt.args.s, root.searchWord, root.searchReg, tt.args.searchType); got != tt.want {
 				t.Errorf("Root.contains() = %v, want %v", got, tt.want)
 			}
 		})
@@ -233,7 +232,7 @@ func Test_searchPosition(t *testing.T) {
 			name: "testNone",
 			args: args{
 				s:  "testtest",
-				re: regexpComple("a", false),
+				re: regexpCompile("a", false),
 			},
 			want: nil,
 		},
@@ -241,7 +240,7 @@ func Test_searchPosition(t *testing.T) {
 			name: "testInCaseSensitive",
 			args: args{
 				s:  "TEST",
-				re: regexpComple("e", false),
+				re: regexpCompile("e", false),
 			},
 			want: [][]int{
 				{1, 2},
@@ -251,7 +250,7 @@ func Test_searchPosition(t *testing.T) {
 			name: "testCaseSensitive",
 			args: args{
 				s:  "TEST",
-				re: regexpComple("e", true),
+				re: regexpCompile("e", true),
 			},
 			want: nil,
 		},
@@ -259,7 +258,7 @@ func Test_searchPosition(t *testing.T) {
 			name: "testMeta",
 			args: args{
 				s:  "test",
-				re: regexpComple("+", false),
+				re: regexpCompile("+", false),
 			},
 			want: nil,
 		},
@@ -267,7 +266,7 @@ func Test_searchPosition(t *testing.T) {
 			name: "testMeta2",
 			args: args{
 				s:  "test",
-				re: regexpComple("t+", false),
+				re: regexpCompile("t+", false),
 			},
 			want: [][]int{
 				{0, 1},
@@ -278,7 +277,7 @@ func Test_searchPosition(t *testing.T) {
 			name: "testM",
 			args: args{
 				s:  "man",
-				re: regexpComple("man", false),
+				re: regexpCompile("man", false),
 			},
 			want: [][]int{
 				{0, 3},
@@ -287,7 +286,7 @@ func Test_searchPosition(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			if got := searchPosition(tt.args.s, tt.args.re); !reflect.DeepEqual(got, tt.want) {
+			if got := searchPositionReg(tt.args.s, tt.args.re); !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("searchPosition() = %v, want %v", got, tt.want)
 			}
 		})
